@@ -29,9 +29,9 @@ class InvalidSpecification(Exception):
         self.path = ''
         for item in ValidationError.path:
             if isinstance(item, int):
-                self.path += '[{}]'.format(item)
+                self.path += f'[{item}]'
             else:
-                self.path += '.{}'.format(item)
+                self.path += f'.{item}'
         self.path = self.path.lstrip('.')
         self.instance = ValidationError.instance
         message = f"{ValidationError.message}.\n\tPath: {self.path}\n\tInstance: {self.instance} Schema: {self.schema}"
@@ -91,6 +91,12 @@ class InvalidInterpCode(Exception):
     """
 
 
+class InvalidTestStatistic(Exception):
+    """
+    InvalidTestStatistic is raised when an invalid/unimplemented test statistic is requested.
+    """
+
+
 class ImportBackendError(Exception):
     """
     MissingLibraries is raised when something is imported by sustained an import error due to missing additional, non-default libraries.
