@@ -13,7 +13,7 @@ import logging
 log = logging.getLogger(__name__)
 
 
-class _BasicPoisson(object):
+class _BasicPoisson:
     def __init__(self, rate):
         self.rate = rate
 
@@ -29,7 +29,7 @@ class _BasicPoisson(object):
         return tensorlib.poisson_logpdf(value, self.rate)
 
 
-class _BasicNormal(object):
+class _BasicNormal:
     def __init__(self, loc, scale):
         self.loc = loc
         self.scale = scale
@@ -48,7 +48,7 @@ class _BasicNormal(object):
         return tensorlib.normal_logpdf(value, self.loc, self.scale)
 
 
-class jax_backend(object):
+class jax_backend:
     """JAX backend for pyhf"""
 
     __slots__ = ['name', 'precision', 'dtypemap', 'default_do_grad']
@@ -221,7 +221,9 @@ class jax_backend(object):
         try:
             dtype = self.dtypemap[dtype]
         except KeyError:
-            log.error('Invalid dtype: dtype must be float, int, or bool.')
+            log.error(
+                'Invalid dtype: dtype must be float, int, or bool.', exc_info=True
+            )
             raise
 
         return jnp.asarray(tensor_in, dtype=dtype)
@@ -304,6 +306,26 @@ class jax_backend(object):
     def reshape(self, tensor, newshape):
         return jnp.reshape(tensor, newshape)
 
+    def ravel(self, tensor):
+        """
+        Return a flattened view of the tensor, not a copy.
+
+        Example:
+
+            >>> import pyhf
+            >>> pyhf.set_backend("jax")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> pyhf.tensorlib.ravel(tensor)
+            DeviceArray([1., 2., 3., 4., 5., 6.], dtype=float64)
+
+        Args:
+            tensor (Tensor): Tensor object
+
+        Returns:
+            `jax.interpreters.xla._DeviceArray`: A flattened array.
+        """
+        return jnp.ravel(tensor)
+
     def einsum(self, subscripts, *operands):
         """
         Evaluates the Einstein summation convention on the operands.
@@ -331,7 +353,7 @@ class jax_backend(object):
 
     def poisson(self, n, lam):
         r"""
-        The continous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
+        The continuous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
         to the probability mass function of the Poisson distribution evaluated
         at :code:`n` given the parameter :code:`lam`.
 
@@ -353,7 +375,7 @@ class jax_backend(object):
                                     (the expected number of events)
 
         Returns:
-            JAX ndarray: Value of the continous approximation to Poisson(n|lam)
+            JAX ndarray: Value of the continuous approximation to Poisson(n|lam)
         """
         n = jnp.asarray(n)
         lam = jnp.asarray(lam)
@@ -468,3 +490,30 @@ class jax_backend(object):
 
         """
         return _BasicNormal(mu, sigma)
+
+    def to_numpy(self, tensor_in):
+        """
+        Convert the TensorFlow tensor to a :class:`numpy.ndarray`.
+
+        Example:
+            >>> import pyhf
+            >>> pyhf.set_backend("jax")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> tensor
+            DeviceArray([[1., 2., 3.],
+                         [4., 5., 6.]], dtype=float64)
+            >>> numpy_ndarray = pyhf.tensorlib.to_numpy(tensor)
+            >>> numpy_ndarray
+            array([[1., 2., 3.],
+                   [4., 5., 6.]])
+            >>> type(numpy_ndarray)
+            <class 'numpy.ndarray'>
+
+        Args:
+            tensor_in (:obj:`tensor`): The input tensor object.
+
+        Returns:
+            :class:`numpy.ndarray`: The tensor converted to a NumPy ``ndarray``.
+
+        """
+        return np.asarray(tensor_in, dtype=tensor_in.dtype)
