@@ -9,7 +9,7 @@ from scipy.stats import norm, poisson
 log = logging.getLogger(__name__)
 
 
-class _BasicPoisson(object):
+class _BasicPoisson:
     def __init__(self, rate):
         self.rate = rate
 
@@ -21,7 +21,7 @@ class _BasicPoisson(object):
         return tensorlib.poisson_logpdf(value, self.rate)
 
 
-class _BasicNormal(object):
+class _BasicNormal:
     def __init__(self, loc, scale):
         self.loc = loc
         self.scale = scale
@@ -34,7 +34,7 @@ class _BasicNormal(object):
         return tensorlib.normal_logpdf(value, self.loc, self.scale)
 
 
-class numpy_backend(object):
+class numpy_backend:
     """NumPy backend for pyhf"""
 
     __slots__ = ['name', 'precision', 'dtypemap', 'default_do_grad']
@@ -206,7 +206,9 @@ class numpy_backend(object):
         try:
             dtype = self.dtypemap[dtype]
         except KeyError:
-            log.error('Invalid dtype: dtype must be float, int, or bool.')
+            log.error(
+                'Invalid dtype: dtype must be float, int, or bool.', exc_info=True
+            )
             raise
 
         return np.asarray(tensor_in, dtype=dtype)
@@ -289,6 +291,26 @@ class numpy_backend(object):
     def reshape(self, tensor, newshape):
         return np.reshape(tensor, newshape)
 
+    def ravel(self, tensor):
+        """
+        Return a flattened view of the tensor, not a copy.
+
+        Example:
+
+            >>> import pyhf
+            >>> pyhf.set_backend("numpy")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> pyhf.tensorlib.ravel(tensor)
+            array([1., 2., 3., 4., 5., 6.])
+
+        Args:
+            tensor (Tensor): Tensor object
+
+        Returns:
+            `numpy.ndarray`: A flattened array.
+        """
+        return np.ravel(tensor)
+
     def einsum(self, subscripts, *operands):
         """
         Evaluates the Einstein summation convention on the operands.
@@ -313,7 +335,7 @@ class numpy_backend(object):
 
     def poisson(self, n, lam):
         r"""
-        The continous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
+        The continuous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
         to the probability mass function of the Poisson distribution evaluated
         at :code:`n` given the parameter :code:`lam`.
 
@@ -335,7 +357,7 @@ class numpy_backend(object):
                                     (the expected number of events)
 
         Returns:
-            NumPy float: Value of the continous approximation to Poisson(n|lam)
+            NumPy float: Value of the continuous approximation to Poisson(n|lam)
         """
         n = np.asarray(n)
         lam = np.asarray(lam)
@@ -450,3 +472,31 @@ class numpy_backend(object):
 
         """
         return _BasicNormal(mu, sigma)
+
+    def to_numpy(self, tensor_in):
+        """
+        Return the input tensor as it already is a :class:`numpy.ndarray`.
+        This API exists only for ``pyhf.tensorlib`` compatibility.
+
+        Example:
+            >>> import pyhf
+            >>> pyhf.set_backend("numpy")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> tensor
+            array([[1., 2., 3.],
+                   [4., 5., 6.]])
+            >>> numpy_ndarray = pyhf.tensorlib.to_numpy(tensor)
+            >>> numpy_ndarray
+            array([[1., 2., 3.],
+                   [4., 5., 6.]])
+            >>> type(numpy_ndarray)
+            <class 'numpy.ndarray'>
+
+        Args:
+            tensor_in (:obj:`tensor`): The input tensor object.
+
+        Returns:
+            :class:`numpy.ndarray`: The tensor converted to a NumPy ``ndarray``.
+
+        """
+        return tensor_in
