@@ -8,7 +8,7 @@ import math
 log = logging.getLogger(__name__)
 
 
-class pytorch_backend(object):
+class pytorch_backend:
     """PyTorch backend for pyhf"""
 
     __slots__ = ['name', 'precision', 'dtypemap', 'default_do_grad']
@@ -172,7 +172,9 @@ class pytorch_backend(object):
         try:
             dtype = self.dtypemap[dtype]
         except KeyError:
-            log.error('Invalid dtype: dtype must be float, int, or bool.')
+            log.error(
+                'Invalid dtype: dtype must be float, int, or bool.', exc_info=True
+            )
             raise
 
         return torch.as_tensor(tensor_in, dtype=dtype)
@@ -189,6 +191,26 @@ class pytorch_backend(object):
     def shape(self, tensor):
         return tuple(map(int, tensor.shape))
 
+    def ravel(self, tensor):
+        """
+        Return a flattened view of the tensor, not a copy.
+
+        Example:
+
+            >>> import pyhf
+            >>> pyhf.set_backend("pytorch")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> pyhf.tensorlib.ravel(tensor)
+            tensor([1., 2., 3., 4., 5., 6.])
+
+        Args:
+            tensor (Tensor): Tensor object
+
+        Returns:
+            `torch.Tensor`: A flattened array.
+        """
+        return tensor.view(-1)
+
     def sum(self, tensor_in, axis=None):
         return (
             torch.sum(tensor_in)
@@ -271,11 +293,13 @@ class pytorch_backend(object):
         max_dim = max(map(len, args))
         try:
             assert not [arg for arg in args if 1 < len(arg) < max_dim]
-        except AssertionError as error:
+        except AssertionError:
             log.error(
-                'ERROR: The arguments must be of compatible size: 1 or %i', max_dim
+                'ERROR: The arguments must be of compatible size: 1 or %i',
+                max_dim,
+                exc_info=True,
             )
-            raise error
+            raise
 
         broadcast = [arg if len(arg) > 1 else arg.expand(max_dim) for arg in args]
         return broadcast
@@ -299,7 +323,7 @@ class pytorch_backend(object):
 
     def poisson(self, n, lam):
         r"""
-        The continous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
+        The continuous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
         to the probability mass function of the Poisson distribution evaluated
         at :code:`n` given the parameter :code:`lam`.
 
@@ -321,7 +345,7 @@ class pytorch_backend(object):
                                     (the expected number of events)
 
         Returns:
-            PyTorch FloatTensor: Value of the continous approximation to Poisson(n|lam)
+            PyTorch FloatTensor: Value of the continuous approximation to Poisson(n|lam)
         """
         return torch.exp(torch.distributions.Poisson(lam).log_prob(n))
 
@@ -434,3 +458,30 @@ class pytorch_backend(object):
 
         """
         return torch.distributions.Normal(mu, sigma)
+
+    def to_numpy(self, tensor_in):
+        """
+        Convert the PyTorch tensor to a :class:`numpy.ndarray`.
+
+        Example:
+            >>> import pyhf
+            >>> pyhf.set_backend("pytorch")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> tensor
+            tensor([[1., 2., 3.],
+                    [4., 5., 6.]])
+            >>> numpy_ndarray = pyhf.tensorlib.to_numpy(tensor)
+            >>> numpy_ndarray
+            array([[1., 2., 3.],
+                   [4., 5., 6.]], dtype=float32)
+            >>> type(numpy_ndarray)
+            <class 'numpy.ndarray'>
+
+        Args:
+            tensor_in (:obj:`tensor`): The input tensor object.
+
+        Returns:
+            :class:`numpy.ndarray`: The tensor converted to a NumPy ``ndarray``.
+
+        """
+        return tensor_in.numpy()
