@@ -6,7 +6,7 @@ import tensorflow_probability as tfp
 log = logging.getLogger(__name__)
 
 
-class tensorflow_backend(object):
+class tensorflow_backend:
     """TensorFlow backend for pyhf"""
 
     __slots__ = ['name', 'precision', 'dtypemap', 'default_do_grad']
@@ -207,7 +207,9 @@ class tensorflow_backend(object):
         try:
             dtype = self.dtypemap[dtype]
         except KeyError:
-            log.error('Invalid dtype: dtype must be float, int, or bool.')
+            log.error(
+                'Invalid dtype: dtype must be float, int, or bool.', exc_info=True
+            )
             raise
 
         tensor = tensor_in
@@ -256,6 +258,27 @@ class tensorflow_backend(object):
     def reshape(self, tensor, newshape):
         return tf.reshape(tensor, newshape)
 
+    def ravel(self, tensor):
+        """
+        Return a flattened view of the tensor, not a copy.
+
+        Example:
+
+            >>> import pyhf
+            >>> pyhf.set_backend("tensorflow")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> t_ravel = pyhf.tensorlib.ravel(tensor)
+            >>> print(t_ravel)
+            tf.Tensor([1. 2. 3. 4. 5. 6.], shape=(6,), dtype=float32)
+
+        Args:
+            tensor (Tensor): Tensor object
+
+        Returns:
+            `tf.Tensor`: A flattened array.
+        """
+        return self.reshape(tensor, -1)
+
     def divide(self, tensor_in_1, tensor_in_2):
         return tf.divide(tensor_in_1, tensor_in_2)
 
@@ -336,11 +359,11 @@ class tensorflow_backend(object):
         max_dim = max(map(tf.size, args))
         try:
             assert not [arg for arg in args if 1 < tf.size(arg) < max_dim]
-        except AssertionError as error:
+        except AssertionError:
             log.error(
                 'ERROR: The arguments must be of compatible size: 1 or %i', max_dim
             )
-            raise error
+            raise
         return [tf.broadcast_to(arg, (max_dim,)) for arg in args]
 
     def einsum(self, subscripts, *operands):
@@ -362,7 +385,7 @@ class tensorflow_backend(object):
 
     def poisson_logpdf(self, n, lam):
         r"""
-        The log of the continous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
+        The log of the continuous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
         to the probability mass function of the Poisson distribution evaluated
         at :code:`n` given the parameter :code:`lam`.
 
@@ -385,13 +408,13 @@ class tensorflow_backend(object):
                                     (the expected number of events)
 
         Returns:
-            TensorFlow Tensor: Value of the continous approximation to log(Poisson(n|lam))
+            TensorFlow Tensor: Value of the continuous approximation to log(Poisson(n|lam))
         """
         return tfp.distributions.Poisson(lam).log_prob(n)
 
     def poisson(self, n, lam):
         r"""
-        The continous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
+        The continuous approximation, using :math:`n! = \Gamma\left(n+1\right)`,
         to the probability mass function of the Poisson distribution evaluated
         at :code:`n` given the parameter :code:`lam`.
 
@@ -414,7 +437,7 @@ class tensorflow_backend(object):
                                     (the expected number of events)
 
         Returns:
-            TensorFlow Tensor: Value of the continous approximation to Poisson(n|lam)
+            TensorFlow Tensor: Value of the continuous approximation to Poisson(n|lam)
         """
         return tf.exp(tfp.distributions.Poisson(lam).log_prob(n))
 
@@ -553,3 +576,31 @@ class tensorflow_backend(object):
 
         """
         return tfp.distributions.Normal(mu, sigma)
+
+    def to_numpy(self, tensor_in):
+        """
+        Convert the TensorFlow tensor to a :class:`numpy.ndarray`.
+
+        Example:
+            >>> import pyhf
+            >>> pyhf.set_backend("tensorflow")
+            >>> tensor = pyhf.tensorlib.astensor([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])
+            >>> print(tensor)
+            tf.Tensor(
+            [[1. 2. 3.]
+             [4. 5. 6.]], shape=(2, 3), dtype=float32)
+            >>> numpy_ndarray = pyhf.tensorlib.to_numpy(tensor)
+            >>> numpy_ndarray
+            array([[1., 2., 3.],
+                   [4., 5., 6.]], dtype=float32)
+            >>> type(numpy_ndarray)
+            <class 'numpy.ndarray'>
+
+        Args:
+            tensor_in (:obj:`tensor`): The input tensor object.
+
+        Returns:
+            :class:`numpy.ndarray`: The tensor converted to a NumPy ``ndarray``.
+
+        """
+        return tensor_in.numpy()
