@@ -39,9 +39,7 @@ def validate(spec, schema_name, version=None):
     schema = load_schema(schema_name, version=version)
     try:
         resolver = jsonschema.RefResolver(
-            base_uri='file://{0:s}'.format(
-                pkg_resources.resource_filename(__name__, 'schemas/')
-            ),
+            base_uri=f"file://{pkg_resources.resource_filename(__name__, 'schemas/'):s}",
             referrer=schema_name,
             store=SCHEMA_CACHE,
         )
@@ -54,7 +52,9 @@ def validate(spec, schema_name, version=None):
 
 
 def options_from_eqdelimstring(opts):
-    document = '\n'.join('{0}: {1}'.format(*opt.split('=', 1)) for opt in opts)
+    document = '\n'.join(
+        f"{opt.split('=', 1)[0]}: {opt.split('=', 1)[1]}" for opt in opts
+    )
     return yaml.full_load(document)
 
 
@@ -65,9 +65,7 @@ class EqDelimStringParamType(click.ParamType):
         try:
             return options_from_eqdelimstring([value])
         except IndexError:
-            self.fail(
-                '{0:s} is not a valid equal-delimited string'.format(value), param, ctx
-            )
+            self.fail(f'{value:s} is not a valid equal-delimited string', param, ctx)
 
 
 def digest(obj, algorithm='sha256'):
@@ -134,3 +132,33 @@ def remove_prefix(text, prefix):
     if text.startswith(prefix):
         return text[len(prefix) :]
     return text
+
+
+def citation(oneline=False):
+    """
+    Get the bibtex citation for pyhf
+
+    Example:
+
+        >>> import pyhf
+        >>> pyhf.utils.citation(True)
+        '@software{pyhf,  author = "{Heinrich, Lukas and Feickert, Matthew and Stark, Giordon}",  title = "{pyhf: v0.6.0}",  version = {0.6.0},  doi = {10.5281/zenodo.1169739},  url = {https://github.com/scikit-hep/pyhf},}@article{pyhf_joss,  doi = {10.21105/joss.02823},  url = {https://doi.org/10.21105/joss.02823},  year = {2021},  publisher = {The Open Journal},  volume = {6},  number = {58},  pages = {2823},  author = {Lukas Heinrich and Matthew Feickert and Giordon Stark and Kyle Cranmer},  title = {pyhf: pure-Python implementation of HistFactory statistical models},  journal = {Journal of Open Source Software}}'
+
+    Keyword Args:
+        oneline (:obj:`bool`): Whether to provide citation with new lines (default) or as a one-liner.
+
+    Returns:
+        citation (:obj:`str`): The citation for this software
+    """
+    path = Path(
+        pkg_resources.resource_filename(
+            __name__, str(Path('data').joinpath('citation.bib'))
+        )
+    )
+    with path.open() as fp:
+        # remove end-of-file newline if there is one
+        data = fp.read().strip()
+
+    if oneline:
+        data = ''.join(data.splitlines())
+    return data
